@@ -1,4 +1,4 @@
-__version__ = "1.0.0"
+__version__ = "1.0.5"
 __author__ = "UltrafunkAmsterdam"
 
 from ._ua import (
@@ -9,4 +9,4 @@ from ._ua import (
     GENERIC_MOBILE,
     GENERIC_WEBKIT,
 )
-from ._util import load_session, save_session, fetch, Session
+from ._util import load_session, save_state, fetch, Session
